ams.opt.param.Param
===================

.. currentmodule:: ams.opt.param

.. autoclass:: Param

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~Param.evaluate
       
       
          ~Param.parse
       
       
          ~Param.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~Param.class_name
      ~Param.n
      ~Param.shape
      ~Param.size
   
   